API docs for “spamfighter.core.message.attribute”

# Module s.c.m.attribute

Part of spamfighter.core.message View Source

Атрибуты сообщений и их домены.

Class | AttributeNotFoundError | Атрибут по имени не был обнаружен.
Class | AttributeDomain | Домент (тип атрибута).
Class | TextAttributeDomain | Тип атрибута "текст сообщения". Основной тип атрибутов при анализе сообщений.
Class | IPAttributeDomain | Атрибут, в котором хранится IP.
Class | IntAttributeDomain | Тип атрибута "целое число".
Class | UniqueIntAttributeDomain | Уникальный атрибут, тип "целое число".
Class | Attribute | Атрибуты характеризуют отправителя и получателя сообщений, они могут нести разную информацию.